@@ -74,6 +74,9 @@ class Note(object):
                 'cc' : {}
              }
 
+    def has_repeats(self):
+        return self.repeat != 1
+
     def shiftable(self):
         if self.no_shift == True:
             return False
@@ -134,7 +137,6 @@ class Note(object):
 
         # index of None will crash the program but shouldn't happen
 
-
         scale_note = scale_notes[index + steps]
 
         n1 = self.copy()
@@ -236,7 +238,13 @@ class Note(object):
         result = self.copy()
         if steps:
             # this is in an in-place edit because the note was already copied
-            (result.name, result.octave) = NOTE_TABLE[result.note_number() + int(2 * steps)]
+
+            new_index = result.note_number() + int(2*steps) + 60
+            if new_index < 0:
+                # this could be improved to work infinitely if the note table implementation were changed
+                raise InvalidNote("negative note range exceeded")
+
+            (result.name, result.octave) = NOTE_TABLE[new_index]
         if octaves:
             result.octave = result.octave + octaves
         return result
@@ -251,6 +259,7 @@ class Note(object):
         """
         What order is this note on the keyboard?
         """
+        # we allow negative octaves for scale math - expecting the instrument to bump them back.
         return NOTES.index(self.name) + (12 * self.octave)
 
     def invert(self, *args):
