@@ -16,9 +16,9 @@ from warpseq.model.directions import *
 
 class Pattern(NewReferenceObject, Directionable):
 
-    __slots__ = [ 'name', 'slots', 'current_slots', 'octave_shift', 'rate', 'scale', 'direction', 'current_direction', 'length', '_iterator', 'obj_id' ]
+    __slots__ = [ 'name', 'slots', 'current_slots', 'octave_shift', 'rate', 'scale', 'direction', 'current_direction', 'mod_expressions_callback', 'length', '_iterator', 'obj_id' ]
 
-    def __init__(self, name=None, slots=None, octave_shift=0, rate=1, scale=None, direction=FORWARD, length=None, obj_id=None):
+    def __init__(self, name=None, slots=None, octave_shift=0, rate=1, scale=None, direction=FORWARD, length=None, mod_expressions_callback=None, obj_id=None):
 
         self.name = name
         self.slots = slots
@@ -26,6 +26,13 @@ class Pattern(NewReferenceObject, Directionable):
         self.rate = rate
         self.scale = scale
 
+        if mod_expressions_callback:
+            # activate the generator
+            mod_expressions_callback = mod_expressions_callback()
+
+        self.mod_expressions_callback = mod_expressions_callback
+
+
         if length is None:
             length = len(slots)
 
