@@ -8,13 +8,13 @@
 
 from ..model.registers import get_first_playing_note
 from .mod_parser import is_deferred_expr, process_expr
-
+from warpseq.api.exceptions import *
 
 class ModExpression(object):
 
     __slots__ = [ 'defer', 'execute_next', 'scale', 'track', 'song', 'pattern' ]
 
-    def __init__(self, song=None, scale=None, track=None, defer=False, pattern=False):
+    def __init__(self, song=None, scale=None, track=None, defer=False, pattern=None):
         self.song = song
         self.defer = defer
         self.execute_next = True
@@ -68,7 +68,13 @@ class ModExpression(object):
                     return input_note
 
             # we ALWAYS need to process non-deferred events
-            input_note = process_expr(self, input_note, expr, deferred=False)
+            try:
+                input_note = process_expr(self, input_note, expr, deferred=False)
+            except InvalidNote:
+                # went way below -5 octaves in mod expression calculation current implementation doesn't allow you to add
+                # that many octaves back
+                input_note = None
+
             if input_note is None:
                 return input_note
 
