@@ -94,7 +94,10 @@ class RealtimeEngine(object):
         # because the mod expression does throw away the note value and capture the value from
         # the guide track...
 
-        if event.type == NOTE_ON and event.note.flags['deferred'] == True:
+        pattern = event.note.from_parser.pattern
+        cb = pattern.mod_expressions_callback # this must be a generator
+
+        if event.type == NOTE_ON and (cb or event.note.flags['deferred'] == True):
 
             # we have to process deferred expressions twice because of the mod events
             # UNLESS we pair the off event.
@@ -105,16 +108,30 @@ class RealtimeEngine(object):
 
             exprs = event.note.flags['deferred_expressions']
             for expr in exprs:
-                #print("track %s has deferrals" % self.track.name)
-
-                #assert event.note.from_scale is not None
-
                 value = self.mod_expressions.do(event.note, expr)
                 if value is None:
                     return
-
                 event.note = value
 
+            #event.note.flags['deferred'] = False
+
+            # run mod expressions callback if attached
+            if cb is not None:
+                value = event.note
+
+                new_mod_expressions = next(cb)
+                for expr in new_mod_expressions:
+                    value = self.mod_expressions.do(event.note, expr)
+                    #if type(value) == Chord:
+                    #    print("NOTES=%s" % value.notes)
+                    if value is None:
+                        return
+                    event.note = value
+
+                    # not entirely sure how this happens but we need to guard against it for now
+                    # this really should be part of "mod_expressions.do"
+                    if type(value) == Chord and len(value.notes) == 1:
+                        event.note = value.notes[0]
 
         # it is possible for mod expressions to take notes and return Chords. We have to do
         # cleanup here to turn this back into a list of notes.
@@ -145,12 +162,17 @@ class RealtimeEngine(object):
 
             for (control, value) in event.note.flags['cc'].items():
                 control = int(control)
-                #command = (MIDI_CONTROLLER_CHANGE & 0xf0) | (self.channel - 1 & 0xf)
-                #self.midi_out.send_message([command, channel & 0x7f, value & 0x7f])
+
 
                 for instrument in self.track.get_instruments_to_play():
 
-                    msg = mido.Message(MIDO_CONTROLLER_CHANGE, channel=instrument.channel-1, control=control, value=value)
+                    #print("SEND MIDI CC: %s/%s" % (control, value))
+
+                    # command = (MIDI_CONTROLLER_CHANGE & 0xf0) | (self.channel - 1 & 0xf)
+                    # self.midi_out.send_message([command, channel & 0x7f, value & 0x7f])
+
+                    msg = mido.Message(MIDO_CONTROLLER_CHANGE, channel=instrument.channel-1, control=control, value=int(value))
+                    #print(msg)
                     instrument.get_midi_out().send(msg)
 
 
